slangpy
=======

The main ``slangpy`` module contains all the basic types
required to load and call slang functions from Python. 

API
---

.. automodule:: slangpy
   :members:
   :imported-members:
   